<?php

namespace Drupal\elb;

use Drupal\Core\Config\ConfigFactory;

/**
 * Class BlacklistService.
 */
class BlacklistService {

  /**
   * The blacklist.
   * @var [] string
   */
  protected $blacklist;

  /**
   * Blacklist exceptions.
   * @var [] string
   */
  protected $blacklist_exceptions;

  /**
   * The Config Factory service.
   * @var \Drupal\Core\Config\ConfigFactory
   */
  protected $config_factory;

  /**
   * Constructs a new BlacklistService object.
   * @param \Drupal\Core\Config\ConfigFactory $config_factory
   *   The config factory.
   */
  function __construct(\Drupal\Core\Config\ConfigFactory $config_factory) {
    $this->config_factory = $config_factory;
    $this->blacklist = $this->getBlacklist();
    $this->blacklist_exceptions = $this->getExceptions();
  }

  /**
   * Return the blacklist.
   * @return [] string
   */
  public function getBlacklist() {
    $blacklist = $this->config_factory->get('elb.settings')->get('blacklist');
    $backlist_array = explode(',', $blacklist);
    return array_map('trim', $backlist_array);
  }

  /**
   * Return the blacklist exceptions.
   * @return [] string
   */
  public function getExceptions() {
    $exceptions = $this->config_factory->get('elb.settings')->get('blacklist_exceptions');
    $exceptions_array = explode(',', $exceptions);
    return array_map('trim', $exceptions_array);
  }

  /**
   * Checks if the given $uri is blacklisted.
   * @param string $uri
   *   The uri string.
   */
  public function isBlacklisted($uri) {
    foreach ($this->blacklist as $prohibited_string) {
      if (substr_count($uri, $prohibited_string) && !$this->isExceptedFromBlacklist($uri)) {
        return TRUE;
      }
    }
    return FALSE;
  }

  /**
   * Checks if the given $uri is excepted from the blacklist.
   * @param string $uri
   *   The uri string.
   */
  public function isExceptedFromBlacklist($uri) {
    foreach ($this->blacklist_exceptions as $exception_string) {
      if (substr_count($uri, $exception_string)) {
        return TRUE;
      }
    }
    return FALSE;
  }
}
